latitude in decimal degrees, positive to the north of the equator. (This
is called lat in the TEOS-10 Matlab code.)
p
sea pressure [dbar], i.e. absolute pressure [dbar] minus 10.1325 dbar
Value
gravitational acceleration [ m/s^2 ]
Details
The present R function works with a wrapper to a C function contained
within the GSW-C system (Version 3.05 dated 2017-07-27, available at
https://github.com/TEOS-10/GSW-C,
as git commit '13ab33cea0e9059d3b3f3dfef78e9591c94af9f8'), which
stems from the GSW-Fortran system (https://github.com/TEOS-10/GSW-Fortran)
which in turn stems from the GSW-Matlab system
(https://github.com/TEOS-10/GSW-Matlab).
Consult http://www.teos-10.org to learn more about
these software systems, their authorships, and the science behind
it all.